pub fn create_instrument_from_def(
def: &PolymarketInstrumentDef,
ts_init: UnixNanos,
) -> Result<InstrumentAny>Expand description
Converts a Polymarket instrument definition into a Nautilus InstrumentAny.
pub fn create_instrument_from_def(
def: &PolymarketInstrumentDef,
ts_init: UnixNanos,
) -> Result<InstrumentAny>Converts a Polymarket instrument definition into a Nautilus InstrumentAny.